@@ -22,7 +22,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: File.h 2375 2007-02-03 04:55:58Z svn $
+ * $Id: File.h 2388 2007-03-10 11:34:50Z svn $
  *****************************************************************************/
 
 #ifndef FILE_H
@@ -398,6 +398,49 @@ public:
         return file_ == NULL;
     };
 
+    /**
+     * ファイル/ディレクトリが存在するかどうかを調べます．
+     *
+     * @param[in] pool プール
+     * @param[in] path パス
+     */
+    static bool is_exist(apr_pool_t *pool, const char *path)
+    {
+        apr_finfo_t info;
+        apr_status_t status;
+
+        status = apr_stat(&info, path, APR_FINFO_MIN, pool);
+
+        return !APR_STATUS_IS_ENOENT(status);
+    }
+
+    /**
+     * ファイル/ディレクトリが書き込み可能かどうかを調べます．
+     *
+     * @param[in] pool プール
+     * @param[in] path パス
+     */
+    static bool is_writable(apr_pool_t *pool, const char *path)
+    {
+        // 本当は info.valid を使って判定した方がいい
+#ifdef WIN32
+        return is_exist(pool, path);
+#else
+        apr_finfo_t info;
+        apr_status_t status;
+
+        status = apr_stat(&info, path, APR_FINFO_TYPE|APR_FINFO_UPROT, pool);
+
+        if (info.filetype & APR_DIR) { // ディレクトリ
+            return ((info.protection & (APR_UREAD|APR_UWRITE|APR_UEXECUTE)) ==
+                    (APR_UREAD|APR_UWRITE|APR_UEXECUTE));
+        } else {
+            return ((info.protection & (APR_UREAD|APR_UWRITE)) ==
+                    (APR_UREAD|APR_UWRITE));
+        }
+#endif
+    }
+
 protected:
     /** プール */
     apr_pool_t *pool_;
