@@ -26,16 +26,16 @@ run make -f GNUmakefile.dist dist-sf
 run make -f GNUmakefile.dist dist-win-sf
 
 (
-    cd doc
+    run cd doc
     run make doc-update
     run cp apache.htm apache-win.htm /home/apache/${PACKAGE}/
 );
 
 (
-    rsync -av --max-size=3000000 . ~/cvs/download/${PACKAGE}
-    cd ~/cvs/download/${PACKAGE}
-    cvs commit -m ""
-    cvs tag release-${VERSION}_`date "+%y%m%d%H%M"`
+    run rsync -av --max-size=3000000 . ~/cvs/download/${PACKAGE}
+    run cd ~/cvs/download/${PACKAGE}
+    run cvs commit -m ""
+    run cvs tag release-${VERSION}_`date "+%y%m%d%H%M"`
 )
 
 echo -e "\033[1;32mOK\033[0m";
